@@ -789,10 +789,9 @@ class WordToken(caching.base.CachingMixin,models.Model):
                     return None
                 if not disambiguate:
                     return '.'.join([str(self),cat,'1'])
-                prev = self.get_previous_context(window=10)
-                foll = self.get_following_context(window=10)
-                context = [str(x) for x in prev] + [str(x) for x in foll]
-                self.Output['Wordnet_sense'] = SEM_PRED.disambiguate_sense(str(self),cat,context,to_string=True)
+                prev = [str(x) for x in self.get_previous_context(window=10)]
+                foll = [str(x) for x in self.get_following_context(window=10)]
+                self.Output['Wordnet_sense'] = SEM_PRED.disambiguate_sense(str(self),cat,prev,foll,to_string=True)
                 self.save()
             return self.Output['Wordnet_sense']
         else:
